import re
import sys

from janome.tokenizer import Tokenizer

# 漢字を表す正規表現
KANJI = re.compile(r"[\u3005-\u3007\u4E00-\u9FFF]")

t = Tokenizer()


def ruby(kanji: str, kana: str) -> str:
    """1つの単語にフリガナを振る"""
    return f"<ruby><rb>{kanji}</rb><rt>{kana}</rt></ruby>"


def furigana(s: str) -> str:
    """指定された文字列にフリガナを振る"""
    result = ""
    for token in t.tokenize(s):
        surface = token.surface
        # 漢字のときはフリガナを振る
        if KANJI.search(surface):
            result += ruby(surface, token.reading)
        else:
            result += surface
    return result


if __name__ == "__main__":
    print(furigana(sys.argv[1]))
