import re
import sys

from sudachipy import dictionary

# 漢字を表す正規表現
KANJI = re.compile(r"[\u3005-\u3007\u4E00-\u9FFF]")

# 末尾のひらがなの正規表現
KANA = re.compile(r"[\u3041-\u309F]+$")

# カタカナをひらがなに変換
K2H = str.maketrans(
    "アイウエオカキクケコサシスセソタチツテトナニヌネノハヒフヘホマミムメモヤユヨラリルレロワヰヱヲンガギグゲゴザジズゼゾダヂヅデドバビブベボパピプペポァィゥェォヵヶッャュョヮ",
    "あいうえおかきくけこさしすせそたちつてとなにぬねのはひふへほまみむめもやゆよらりるれろわゐゑをんがぎぐげござじずぜぞだぢづでどばびぶべぼぱぴぷぺぽぁぃぅぇぉゕゖっゃゅょゎ",
)

t = dictionary.Dictionary().create()


def ruby(kanji: str, kana: str) -> str:
    """1つの単語にフリガナを振る"""
    kana = kana.translate(K2H)
    okuri = ""
    if m := KANA.search(kanji):
        okuri = m[0]
        # 送り仮名を削除
        kanji = kanji.removesuffix(okuri)
        kana = kana.removesuffix(okuri)

    return f"<ruby><rb>{kanji}</rb><rt>{kana}</rt></ruby>{okuri}"


def furigana(s: str) -> str:
    """指定された文字列にフリガナを振る"""
    result = ""
    for token in t.tokenize(s):
        surface = token.surface()
        # 漢字のときはフリガナを振る
        if KANJI.search(surface):
            result += ruby(surface, token.reading_form())
        else:
            result += surface
    return result


if __name__ == "__main__":
    print(furigana(sys.argv[1]))
